@@ -1,7 +1,7 @@
 aggregate_atomic_numeric <- function(x, FUN, ...) {
   x <- FUN(x, ...)
   if (!identical(length(x), 1L)) {
-    err("`fun` must return a scalar.")
+    abort_chk("`fun` must return a scalar.")
   }
   x
 }
@@ -11,7 +11,7 @@ aggregate_atomic_numerics <- function(x, fun, ...) {
   ndims <- length(dims)
   x <- abind(x, along = ndims + 1L)
   x <- apply(x, MARGIN = 1:ndims, FUN = fun, ...)
-  if (!identical(dims(x), dims)) err("`fun` must return a scalar.")
+  if (!identical(dims(x), dims)) abort_chk("`fun` must return a scalar.")
   x
 }
 
