@@ -1,28 +1,21 @@
-#' Number of MCMC chains
+#' @export
+universals::nchains
+
+#' @details Always 1L.
 #'
-#' Gets the number of chains of an MCMC object.
-#'
-#' @param x An MCMC object
-#' @param ... Unused
-#' @return A count indicating the number of MCMC chains
+#' @inherit universals::nterms
 #' @export
 #'
 #' @examples
 #' nchains(nlist(x = 1:2))
-#' nchains(nlists(nlist(x = c(2, 9)), nlist(x = c(1, 7))))
-#' nchains(split_chains(nlists(nlist(x = c(2, 9)), nlist(x = c(1, 7)))))
-nchains <- function(x, ...) {
-  UseMethod("nchains")
-}
-
-#' @describeIn nchains Number of chains of an nlists_object.
-#'
-#' Always 1L.
-#' @export
 nchains.nlist <- function(x, ...) 1L
 
-#' @describeIn nchains Number of chains of an nlists_object.
+#' @inherit universals::nterms
 #' @export
+#'
+#' @examples
+#' nchains(nlists(nlist(x = c(2, 9)), nlist(x = c(1, 7))))
+#' nchains(split_chains(nlists(nlist(x = c(2, 9)), nlist(x = c(1, 7)))))
 nchains.nlists <- function(x, ...) {
   nchains <- attr(x, "nchains")
   if (is.null(nchains)) {
